%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% Definitions of builtins of module Directory:
%

:- module(prim_directory,
	  [prim_doesFileExist/2,prim_doesDirectoryExist/2,
	   prim_getModificationTime/2,prim_fileSize/2,
	   prim_getCurrentDirectory/1,prim_getDirectoryContents/2,
	   prim_createDirectory/2,
	   prim_removeFile/2]).

:- use_module('../prologbasics').
:- use_module('../basics').
:- use_module(library(system)).

prim_doesFileExist(FileName,Exists) :-
	string2Atom(FileName,FName),
	(existsFile(FName) -> Exists='Prelude.True' ; Exists='Prelude.False').

prim_doesDirectoryExist(DirName,Exists) :-
	string2Atom(DirName,Dir),
	(existsDirectory(Dir) -> Exists='Prelude.True' ; Exists='Prelude.False').

prim_getModificationTime(FileName,'Time.CTime'(Time)) :-
	string2Atom(FileName,FName),
	fileModTime(FName,Time).

prim_fileSize(FileName,Size) :-
	string2Atom(FileName,FName),
	fileSize(FName,Size).

prim_getCurrentDirectory(DirName) :-
	working_directory(Dir,Dir),
	atom2String(Dir,DirName).

prim_getDirectoryContents(DirName,EntryNames) :-
	string2Atom(DirName,Dir),
	directory_files(Dir,Entries),
	map2(atom2String,Entries,EntryNames).

prim_createDirectory(DirName,'Prelude.()') :-
	string2Atom(DirName,DName),
	make_directory(DName).

prim_removeFile(FileName,'Prelude.()') :-
	string2Atom(FileName,FName),
	deleteFile(FName).


